import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/device_managment/all_devices/models/device_status.dart';
import 'package:syncrow_web/pages/device_managment/all_devices/models/devices_model.dart';
import 'package:syncrow_web/pages/device_managment/living_room_switch/bloc/living_room_bloc.dart';
import 'package:syncrow_web/pages/device_managment/living_room_switch/helper/living_room_helper.dart';
import 'package:syncrow_web/utils/color_manager.dart';

class LivingRoomDeviceControl extends StatelessWidget with LivingRoomHelper {
  const LivingRoomDeviceControl({super.key, required this.device});

  final AllDevicesModel device;

  @override
  Widget build(BuildContext context) {
    return BlocProvider(
      create: (context) =>
          LivingRoomBloc()..add(LivingRoomFetchDeviceStatus(device.uuid!)),
      child: BlocListener<LivingRoomBloc, LivingRoomState>(
        listener: (context, state) {
          if (state is LivingRoomControlSuccess) {
            context
                .read<LivingRoomBloc>()
                .add(LivingRoomFetchDeviceStatus(device.uuid!));
          }
        },
        child: BlocBuilder<LivingRoomBloc, LivingRoomState>(
          builder: (context, state) {
            if (state is LivingRoomDeviceStatusLoading) {
              return const Center(child: CircularProgressIndicator());
            } else if (state is LivingRoomDeviceStatusLoaded) {
              return _buildStatusControls(state.status.status);
            } else {
              return const Center(child: Text('Error fetching status'));
            }
          },
        ),
      ),
    );
  }

  Widget _buildStatusControls(List<Status> statuses) {
    return GridView.builder(
      padding: const EdgeInsets.symmetric(horizontal: 40),
      shrinkWrap: true,
      physics: const NeverScrollableScrollPhysics(),
      gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
        crossAxisCount: 3,
        mainAxisExtent: 133,
        crossAxisSpacing: 12,
        mainAxisSpacing: 12,
      ),
      itemCount: 3,
      itemBuilder: (context, index) {
        final status = statuses[index];

        return Container(
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(20),
            color: ColorsManager.greyColor.withOpacity(0.2),
            border: Border.all(color: ColorsManager.boxDivider),
          ),
          padding: const EdgeInsets.all(16),
          child: livingRoomControlWidgets(
              value: status.value, code: status.code, deviceId: device.uuid!),
        );
      },
    );
  }
}
